@@ -9,11 +9,14 @@ from logonlabs.api import ping,\
     validateLogin,\
     redirectLogin,\
     createEvent,\
-    updateEvent
-
+    updateEvent,\
+    refreshToken,\
+    revokeToken
+	
 from logonlabs.allowableValues import identityProviders,\
     eventTypes,\
-    localVallidationValues
+    localVallidationValues,\
+	forceAuthenticationTypes
 
 class Logonlabs(object):
     def __init__(self, app_id, app_secret, api_path=DEFAULT_BASE_URL):
@@ -40,7 +43,8 @@ class Logonlabs(object):
         client_data=None,
         callback_url=None,
         destination_url=None,
-        tags=None):
+        tags=None,
+		force_reauthentication=None):
         params = {
             'app_id': self.app_id
         }
@@ -68,6 +72,12 @@ class Logonlabs(object):
 
         if tags is not None:
             params['tags'] = tags
+			
+		if force_reauthentication is not None:
+            if force_reauthentication in forceAuthenticationTypes:
+                params['force_reauthentication'] = force_reauthentication
+            else:
+                raise Exception('{} must be either off, attempt, or force'.format(force_reauthentication))	
 
         response = startLogin(self.api_path, params)
         responseObject = response.json()
@@ -170,3 +180,41 @@ class Logonlabs(object):
             params['tags'] = tags
 
         return updateEvent(self.api_path, params, headers)
+		
+	def refreshToken(self,
+        identity_provider_id=None,
+		token=None):
+        params = {
+            'app_id': self.app_id
+        }
+        headers = {
+            'x-app-secret': self.app_secret
+        }
+
+
+        if identity_provider_id is not None:
+            params['identity_provider_id'] = identity_provider_id
+
+        if token is not None:
+            params['token'] = token
+
+        return refreshToken(self.api_path, params, headers)
+		
+	def revokeToken(self,
+        identity_provider_id=None,
+		token=None):
+        params = {
+            'app_id': self.app_id
+        }
+        headers = {
+            'x-app-secret': self.app_secret
+        }
+
+
+        if identity_provider_id is not None:
+            params['identity_provider_id'] = identity_provider_id
+
+        if token is not None:
+            params['token'] = token
+
+        return revokeToken(self.api_path, params, headers)
